@@ -14,14 +14,37 @@
 #    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+from io import BytesIO
+
 from django.shortcuts import render
+from qrcode import QRCode
+import base64
 
 from hidlroute.vpn.views import BaseVPNDeviceConfigView
 
 
 class WireguardDeviceVPNConfigView(BaseVPNDeviceConfigView):
+    CLIENT_CONFIG_FILENAME = "wg0.conf"
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
     def post(self, request, device):
-        return render(request, "hidl_wg/config_view.html", {"device": device})
+        with BytesIO() as buffer:
+            config = device.generate_config()
+
+            qrcode = QRCode()
+            qrcode.add_data(config.as_str())
+            image = qrcode.make_image()
+            image.save(buffer, format="png")
+            config_qr_base64 = base64.b64encode(buffer.getbuffer()).decode("utf-8")
+            return render(
+                request,
+                "hidl_wg/config_view.html",
+                {
+                    "device": device,
+                    "config": config,
+                    "config_qr_base64": config_qr_base64,
+                    "client_config_filename": WireguardDeviceVPNConfigView.CLIENT_CONFIG_FILENAME,
+                },
+            )
